/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.db;

import java.sql.*;
import java.util.*;
import com.silverwrist.util.StringUtil;

public class SQLUtil
{
  /*--------------------------------------------------------------------------------
   * Internal functions
   *--------------------------------------------------------------------------------
   */

  private static java.util.Date convertDateTimeString(String dstr) throws SQLException
  {
    if (dstr==null)
      return null;  // null values are the same

    try
    { // do almost the reverse process of formatting it into a string
      GregorianCalendar cal = new GregorianCalendar(new SimpleTimeZone(0,"UTC"));
      cal.set(Calendar.YEAR,Integer.parseInt(dstr.substring(0,4)));
      cal.set(Calendar.MONTH,Integer.parseInt(dstr.substring(5,7)) - 1 + Calendar.JANUARY);
      cal.set(Calendar.DAY_OF_MONTH,Integer.parseInt(dstr.substring(8,10)));
      cal.set(Calendar.HOUR_OF_DAY,Integer.parseInt(dstr.substring(11,13)));
      cal.set(Calendar.MINUTE,Integer.parseInt(dstr.substring(14,16)));
      cal.set(Calendar.SECOND,Integer.parseInt(dstr.substring(17,19)));
      return cal.getTime();

    } // end try
    catch (NumberFormatException e)
    { // the NumberFormatException becomes an SQLException
      throw new SQLException("invalid DATETIME field format");

    } // end catch

  } // end convertDateString

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  public static String encodeString(String str)
  {
    return StringUtil.encodeStringSQL(str);

  } // end encodeString

  public static String encodeStringArg(String str)
  {
    if (str==null)
      return "NULL";
    StringBuffer b = new StringBuffer("'");
    b.append(StringUtil.encodeStringSQL(str)).append('\'');
    return b.toString();

  } // end encodeStringArg

  public static String encodeStringWildcards(String str)
  {
    if ((str.indexOf('_')<0) && (str.indexOf('%')<0))
      return StringUtil.encodeStringSQL(str);

    StringBuffer buf = new StringBuffer();
    for (int i=0; i<str.length(); i++)
    { // loop through the string encoding its characters
      char c = str.charAt(i);
      switch (c)
      {
	case '\'':
	  buf.append("\'\'");
	  break;

	case '_':
	  buf.append("\\_");
	  break;

	case '%':
	  buf.append("\\%");
	  break;

	default:
	  buf.append(c);
	  break;

      } // end switch

    } // end for

    return buf.toString();

  } // end encodeStringWildcards

  public static String encodeDate(java.util.Date d)
  {
    // Break down the date as a UTC value.
    GregorianCalendar cal = new GregorianCalendar(new SimpleTimeZone(0,"UTC"));
    cal.setTime(d);

    // Create the two string buffers converting the date.
    StringBuffer rc = new StringBuffer();
    StringBuffer conv = new StringBuffer();
    String c;
    
    // Encode the year first.
    conv.append("0000").append(cal.get(Calendar.YEAR));
    c = conv.toString();
    rc.append(c.substring(c.length()-4)).append('-');

    // Now the month...
    conv.setLength(0);
    conv.append("00").append(cal.get(Calendar.MONTH) - Calendar.JANUARY + 1);
    c = conv.toString();
    rc.append(c.substring(c.length()-2)).append('-');

    // And the day...
    conv.setLength(0);
    conv.append("00").append(cal.get(Calendar.DAY_OF_MONTH));
    c = conv.toString();
    rc.append(c.substring(c.length()-2)).append(' ');

    // And the hour...
    conv.setLength(0);
    conv.append("00").append(cal.get(Calendar.HOUR_OF_DAY));
    c = conv.toString();
    rc.append(c.substring(c.length()-2)).append(':');

    // And the minute...
    conv.setLength(0);
    conv.append("00").append(cal.get(Calendar.MINUTE));
    c = conv.toString();
    rc.append(c.substring(c.length()-2)).append(':');

    // And the second...
    conv.setLength(0);
    conv.append("00").append(cal.get(Calendar.SECOND));
    c = conv.toString();
    rc.append(c.substring(c.length()-2));

    // This is the resulting date/time value.
    return rc.toString();

  } // end encodeDate

  public static java.util.Date getFullDateTime(ResultSet rs, String column) throws SQLException
  {
    return convertDateTimeString(rs.getString(column));

  } // end getFullDateTime

  public static java.util.Date getFullDateTime(ResultSet rs, int column) throws SQLException
  {
    return convertDateTimeString(rs.getString(column));

  } // end getFullDateTime

} // end class SQLUtil

